======
choixe
======

.. image:: https://github.com/eyecan-ai/choixe/workflows/Python%20package/badge.svg

.. image:: https://img.shields.io/pypi/v/choixe.svg
        :target: https://pypi.python.org/pypi/choixe

.. image:: https://readthedocs.org/projects/choixe/badge/?version=latest
        :target: https://choixe.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Configurations Superpowers

KNOWN ISSUES
------------

* In TOML mixed types array is not allowed! 